using System;
using System.Collections;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Drawing.Design;
using System.Windows.Forms;
using System.Windows.Forms.Design;
using System.Windows.Forms.Design.Behavior;
using Shared;
using Infragistics.Shared;
using Infragistics.Win;

namespace Shared.BaseClasses
{
    [System.Security.Permissions.PermissionSet(System.Security.Permissions.SecurityAction.Demand, Name = "FullTrust")]
    public class OptionSetBaseDesigner : ControlDesigner
    {
        #region .   Variables   .
        // References to designer services, for convenience.
        private IComponentChangeService changeService = null;
        private ISelectionService selectionService = null;
        private BehaviorService behaviorSvc = null;

        // This is the collection of DesignerActionLists that
        // defines the smart tags offered on the control. 
        private DesignerActionListCollection actionLists = null;
        #endregion

        #region .   Numeric Editor Base Designer   .
        public OptionSetBaseDesigner()
        {   
        }

        #region .   Dispose   .
        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
            }

            base.Dispose(disposing);
        }
        #endregion

        #region .   Initialize   .
        // This method is where the designer initializes its state when
        // it is created.
        public override void Initialize(IComponent component)
        {
            base.Initialize(component);

            // Connect to various designer services.
            InitializeServices();
        }

        #region . New Component   .
        // This demonstrates changing the appearance of a control while
        // it is being designed. In this case, the BackColor property is
        // set to LightBlue. 
        public override void InitializeNewComponent(IDictionary defaultValues)
        {
            base.InitializeNewComponent(defaultValues);
        }
        #endregion

        #region . Services   .
        // This utility method connects the designer to various services.
        // These references are cached for convenience.
        private void InitializeServices()
        {
            // Acquire a reference to IComponentChangeService.
            this.changeService =
                GetService(typeof(IComponentChangeService))
                as IComponentChangeService;

            // Acquire a reference to ISelectionService.
            this.selectionService =
                GetService(typeof(ISelectionService))
                as ISelectionService;

            // Acquire a reference to BehaviorService.
            this.behaviorSvc =
                GetService(typeof(BehaviorService))
                as BehaviorService;
        }
        #endregion

        #endregion

        #endregion

        #region .   Designer Action List   .
        // This method creates the DesignerActionList on demand, causing
        // smart tags to appear on the control being designed.
        public override DesignerActionListCollection ActionLists
        {
            get
            {
                if (null == actionLists)
                {
                    actionLists = new DesignerActionListCollection();

                    actionLists.Add(
                        new ActionList(this.Component));
                }

                return actionLists;
            }
        }
        #endregion

        public class ActionList : System.ComponentModel.Design.DesignerActionList
        {
            #region .   Action List   .
            // Cache a reference to the control.
            private OptionSetBase relatedControl;

            //The constructor associates the control 
            //with the smart tag list.
            public ActionList(IComponent component)
                : base(component)
            {
                this.relatedControl = component as OptionSetBase;
            }
            #endregion

            #region .   Variables   .

            #region .   Items   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            [DesignerSerializationVisibility(DesignerSerializationVisibility.Content)]
            [Editor("Infragistics.Win.UltraWinEditors.ItemsUITypeEditor, Infragistics2.Win.v10.3.Design, Version=10.3.20103.1000, Culture=neutral, PublicKeyToken=7dd5c3163f2cd0cb", typeof(UITypeEditor))]
            public ValueListItemsCollection Items
            {
                get
                {
                    return this.relatedControl.Items;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["Items"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #endregion

            #region .   Get Sorted Action Items   .
            // This method creates and populates the DesignerActionItemCollection which is used to 
            // display smart tag items.
            public override DesignerActionItemCollection GetSortedActionItems()
            {
                DesignerActionItemCollection items = new DesignerActionItemCollection();

                #region .   Appearance   .

                #region .   Items   .
                items.Add(new DesignerActionPropertyItem(
                    "Items",
                    "Items:",
                    "Appearance",
                    "Returns the controls ListItems collection, which corresponds directly to the editors ValueListItems collection."));
                #endregion

                #endregion

                return items;
            }
            #endregion
        }
    }
}